Linux Sound subsystem development
 help / color / mirror / Atom feed
* Patch for Creative SB AWE64 Gold ISAPnP card.
@ 2000-05-26  4:27 Pål-Kristian Engstad
  0 siblings, 0 replies; only message in thread
From: Pål-Kristian Engstad @ 2000-05-26  4:27 UTC (permalink / raw)
  To: linux-sound

The following patch worked like a charm for me.
No more need for isapnp tools!

PKE.

--- sb_card.c.orig Thu May 25 09:15:18 2000
+++ sb_card.c   Thu May 25 21:22:17 2000
@@ -40,7 +40,9 @@
  *  Thanks to Gaël Quéri and Alessandro Zummo for testing and fixes.
  *  Paul E. Laufer <pelaufer@csupomona.edu>
  *
  * 06-05-2000 added another card. Daniel M. Newman <dmnewman@pobox.com>
  *
  */
 
@@ -452,6 +454,11 @@
        ISAPNP_VENDOR('@','X','@'), ISAPNP_FUNCTION(0x2001),
        ISAPNP_VENDOR('@','H','@'), ISAPNP_FUNCTION(0x0001),
        1,0,0,0},
+   {"Creative SB AWE64 Gold",
+           ISAPNP_VENDOR('C','T','L'), ISAPNP_DEVICE(0x00B2),
+           ISAPNP_VENDOR('C','T','L'), ISAPNP_FUNCTION(0x0044),
+           0,0,0,0,
+           0,1,1,-1},
    {0}
 };
                       

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2000-05-26  4:27 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -40,7 +40,9 @@
  *  Paul E. Laufer <pelaufer@csupomona.edu>
  *
- * 06-05-2000 added another card. Daniel M. Newman <dmnewman@pobox.com>
+ * 06-05-2000 Added another card. Daniel M. Newman <dmnewman@pobox.com>
+ *
+ * 25-05-2000 Added Creative SB AWE64 Gold. Pål-Kristian Engstad <engstad@att.net>
  *
  */
2000-05-26  4:27 Patch for Creative SB AWE64 Gold ISAPnP card Pål-Kristian Engstad

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox